# PySentry - pip-audit Benchmark Report

**Generated:** 2025-10-18 06:24:51
**Duration:** 1m 52.84s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.308s) - 29.75x faster than slowest
- **Memory Efficient:** pysentry-osv (10.44 MB) - 8.97x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.171s) - 47.45x faster than slowest
- **Memory Efficient:** pysentry-pypi (7.92 MB) - 11.83x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.902s) - 22.87x faster than slowest
- **Memory Efficient:** pysentry-osv (9.82 MB) - 9.57x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.624s) - 26.46x faster than slowest
- **Memory Efficient:** pysentry-osv (9.78 MB) - 9.36x less memory than highest

## Test Environment

- **Platform:** Linux-6.14.0-1012-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.65 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.308s | 1.00x |
| 🥈 pysentry-osv | 0.642s | 2.09x |
|  pysentry-all-sources | 1.128s | 3.66x |
|  pysentry-pypa | 1.286s | 4.18x |
|  pip-audit-default | 9.158s | 29.75x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.44 MB | 1.00x |
| 🥈 pysentry-pypi | 12.07 MB | 1.16x |
|  pip-audit-default | 45.62 MB | 4.37x |
|  pysentry-pypa | 60.79 MB | 5.82x |
|  pysentry-all-sources | 93.62 MB | 8.97x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.171s | 1.00x |
| 🥈 pysentry-osv | 0.544s | 3.19x |
|  pysentry-pypa | 0.812s | 4.76x |
|  pysentry-all-sources | 0.918s | 5.38x |
|  pip-audit-default | 8.104s | 47.45x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 7.92 MB | 1.00x |
| 🥈 pysentry-osv | 9.41 MB | 1.19x |
|  pip-audit-default | 44.54 MB | 5.62x |
|  pysentry-pypa | 60.47 MB | 7.63x |
|  pysentry-all-sources | 93.73 MB | 11.83x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.902s | 1.00x |
| 🥈 pysentry-pypa | 1.488s | 1.65x |
|  pysentry-all-sources | 2.628s | 2.91x |
|  pysentry-osv | 2.705s | 3.00x |
|  pip-audit-default | 20.622s | 22.87x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.82 MB | 1.00x |
| 🥈 pysentry-pypi | 12.57 MB | 1.28x |
|  pip-audit-default | 47.75 MB | 4.86x |
|  pysentry-pypa | 53.46 MB | 5.45x |
|  pysentry-all-sources | 93.97 MB | 9.57x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.624s | 1.00x |
| 🥈 pysentry-pypa | 1.394s | 2.23x |
|  pysentry-all-sources | 2.476s | 3.97x |
|  pysentry-osv | 2.738s | 4.39x |
|  pip-audit-default | 16.509s | 26.46x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.78 MB | 1.00x |
| 🥈 pysentry-pypi | 12.11 MB | 1.24x |
|  pysentry-pypa | 43.66 MB | 4.47x |
|  pip-audit-default | 47.31 MB | 4.84x |
|  pysentry-all-sources | 91.52 MB | 9.36x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.298s, Min: 0.171s, Max: 2.738s

- **Memory Usage:** Avg: 42.21 MB, Min: 7.92 MB, Max: 93.97 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 13.598s, Min: 8.104s, Max: 20.622s

- **Memory Usage:** Avg: 46.31 MB, Min: 44.54 MB, Max: 47.75 MB

- **Success Rate:** 100.0% (4/4)